@@ -44,16 +44,16 @@ public:
                         EventType* eventType);
 
     // reimplemented from QAbstractItemModel
-    QVariant data(const QModelIndex&, int) const;
-    Qt::ItemFlags flags(const QModelIndex&) const;
+    QVariant data(const QModelIndex&, int) const Q_DECL_OVERRIDE;
+    Qt::ItemFlags flags(const QModelIndex&) const Q_DECL_OVERRIDE;
     QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const;
+                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
     QModelIndex index(int row, int column = 0,
-                      const QModelIndex &parent = QModelIndex()) const;
-    QModelIndex parent(const QModelIndex &index) const;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const;
-    void sort(int column, Qt::SortOrder order);
+                      const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    QModelIndex parent(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    void sort(int column, Qt::SortOrder order) Q_DECL_OVERRIDE;
 
     void setFilter(QString filter);
     void setEventType(EventType*);
